@@ -3,19 +3,6 @@ from diffuzz.scan_types import Sniper, DualSniper, BatteringRam, DualBatteringRa
 from httpinsert.insertion_points import find_insertion_points
 from httpdiff import Item
 
-def create_custom_blob(word):
-    word=word.encode()
-    class CustomBlob:
-        def __init__(self):
-            self.item = Item()
-
-        def add_line(self,line,payload=None):
-            self.item.add_line(str(line.count(word)))
-
-        def find_diffs(self,line):
-            return self.item.find_diffs("",str(line.count(word)))
-    return CustomBlob
-
 def main():
     options = Options()
     insertion_points = find_insertion_points(options.req,default=True,location="Manual")
@@ -34,25 +21,22 @@ def main():
         options.logger.warn("No insertion points found!")
         return
 
-    custom_blob = None
-    if options.args.word:
-        custom_blob = create_custom_blob(options.args.word)
     if options.args.scan_type.lower() == "sniper":
-        fuzzer = Sniper(options, custom_blob=custom_blob)
+        fuzzer = Sniper(options)
     elif options.args.scan_type.lower() == "dualsniper":
-        fuzzer = DualSniper(options, custom_blob=custom_blob)
+        fuzzer = DualSniper(options)
     elif options.args.scan_type.lower() == "pitchfork":
-        fuzzer = PitchFork(options, custom_blob=custom_blob)
+        fuzzer = PitchFork(options)
     elif options.args.scan_type.lower() == "dualpitchfork":
-        fuzzer = DualPitchFork(options, custom_blob=custom_blob)
+        fuzzer = DualPitchFork(options)
     elif options.args.scan_type.lower() == "clusterbomb":
-        fuzzer = ClusterBomb(options, custom_blob=custom_blob)
+        fuzzer = ClusterBomb(options)
     elif options.args.scan_type.lower() == "dualclusterbomb":
-        fuzzer = DualClusterBomb(options, custom_blob=custom_blob)
+        fuzzer = DualClusterBomb(options)
     elif options.args.scan_type.lower() == "batteringram":
-        fuzzer = BatteringRam(options, custom_blob=custom_blob)
+        fuzzer = BatteringRam(options)
     elif options.args.scan_type.lower() == "dualbatteringram":
-        fuzzer = DualBatteringRam(options, custom_blob=custom_blob)
+        fuzzer = DualBatteringRam(options)
     else:
         raise NotImplementedError(f"Scan type '{options.args.scan_type}' is not implemented")
     fuzzer.scan(insertion_points)
